@@ -10,11 +10,6 @@ sub run {
 
     my $is_tagged = $state->vc->exists_tagged_version($ver);
 
-    # are they just compulsively running shipit?
-    if ($is_tagged && ! $state->vc->are_local_diffs) {
-        die "No local changes, and version on disk is already tagged.  Nothing to do.\n";
-    }
-
     print "Current version is: $ver\n";
     my $def = "";
 
@@ -26,6 +21,12 @@ sub run {
     my $newver = $term->readline("Next/release version? $def");
     $newver ||= $ver;
 
+    # are they just compulsively running shipit?  i.e., they just asked for same
+    # version as something tagged & no local diffs....
+    if ($is_tagged && $newver eq $ver && ! $state->vc->are_local_diffs) {
+        die "No local changes, and version on disk is already tagged.  Nothing to do.\n";
+    }
+
     # check to make sure they're not releasing a version that's already tagged
     if ($state->vc->exists_tagged_version($newver)) {
         die "Sorry, version '$newver' is already tagged.  Stopping.\n";
